-------------------------------------------------------------
-- MDB Tools - A library for reading MS Access database files
-- Copyright (C) 2000-2004 Brian Bruns
-- Files in libmdb are licensed under LGPL and the utilities under
-- the GPL, see COPYING.LIB and COPYING files respectively.
-- Check out http://mdbtools.sourceforge.net
-------------------------------------------------------------

-- for i  in Categories Customers Employees Suppliers Products OrderDetails Orders Shippers ; do cat $i.sql | psql NW  ; done


DROP TABLE OrderDetails;
DROP TABLE Orders;
DROP TABLE Shippers;
DROP TABLE Products;
DROP TABLE Employees;
DROP TABLE Customers;
DROP TABLE Suppliers;
DROP TABLE Categories;


CREATE TABLE Categories
 (
	CategoryID			Integer primary key, 
	CategoryName			varchar (30), 
	Description			varchar(255), 
	Picture			varchar (255)
);
-- CREATE ANY INDEXES ...


CREATE TABLE Customers
 (
	CustomerID			varchar (10) primary key, 
	CompanyName			varchar (80), 
	ContactName			varchar (60), 
	ContactTitle			varchar (60), 
	Address			varchar (120), 
	City			varchar (30), 
	Region			varchar (30), 
	PostalCode			varchar (20), 
	Country			varchar (30), 
	Phone			varchar (48), 
	Fax			varchar (48)
);
-- CREATE ANY INDEXES ...


CREATE TABLE Employees
 (
	EmployeeID			Integer primary key, 
	LastName			varchar (40), 
	FirstName			varchar (20), 
	Title			varchar (60), 
	TitleOfCourtesy			varchar (50), 
	BirthDate			date , 
	HireDate			date , 
	Address			varchar (120), 
	City			varchar (30), 
	Region			varchar (30), 
	PostalCode			varchar (20), 
	Country			varchar (30), 
	HomePhone			varchar (48), 
	Extension			varchar (8), 
	Photo			varchar (510), 
	Notes			text , 
	ReportsTo			Integer
);

-- CREATE ANY INDEXES ...

CREATE TABLE Shippers
 (
	ShipperID			Integer primary key, 
	CompanyName			varchar (80), 
	Phone			varchar (48)
);



-- CREATE ANY INDEXES ...


CREATE TABLE Suppliers
 (
	SupplierID			Integer primary key, 
	CompanyName			varchar (80), 
	ContactName			varchar (60), 
	ContactTitle			varchar (60), 
	Address			varchar (120), 
	City			varchar (30), 
	Region			varchar (30), 
	PostalCode			varchar (20), 
	Country			varchar (30), 
	Phone			varchar (48), 
	Fax			varchar (48), 
	HomePage			varchar (255)
);
-- CREATE ANY INDEXES ...


CREATE TABLE Products
 (
	ProductID			Integer primary key, 
	ProductName			varchar (80), 
	SupplierID			Integer references Suppliers, 
	CategoryID			Integer references Categories, 
	QuantityPerUnit			varchar (40), 
	UnitPrice			real, 
	UnitsInStock			Integer, 
	UnitsOnOrder			Integer, 
	ReorderLevel			Integer, 
	Discontinued			Boolean
);
-- CREATE ANY INDEXES ...



CREATE TABLE Orders
 (
	OrderID			Integer primary key, 
	CustomerID			varchar (10) references Customers, 
	EmployeeID			Integer references Employees, 
	OrderDate			timestamp,
	RequiredDate			timestamp,
	ShippedDate			timestamp,
	ShipVia			Integer references Shippers, 
	Freight			real, 
	ShipName			varchar (80), 
	ShipAddress			varchar (120), 
	ShipCity			varchar (30), 
	ShipRegion			varchar (30), 
	ShipPostalCode			varchar (20), 
	ShipCountry			varchar (30)
);
-- CREATE ANY INDEXES ...



CREATE TABLE OrderDetails
 (
	OrderID			Integer references Orders, 
	ProductID			Integer references Products, 
	UnitPrice			real, 
	Quantity			Integer, 
	Discount			real,
	primary key (OrderID,ProductID)
);
-- CREATE ANY INDEXES ...





-- CREATE ANY Relationships ...

-- relationships are not supported for access
